# s-visual-test

Helper component to test if the visual of a specific components look well with different property values, it's also test specified events and methods

![Preview](src/assets/preview.png)

## Installation
```
npm i @solution5520/s-visual-test
```


## Importing
### Locally
Install per component as needed
```javascript
import VisualTest from "@solution5520/s-visual-test"

export default {
  components: { VisualTest },
  // ... rest of component config
}
```


## Usage
### With all options
In template:
```javascript
<VisualTest :componentFilename="componentFilename"
      :defaultValue="defaultValue"
      :value="model"
      :props="props"
      :events="events"
      :methods="methods" />
```
In script:
```javascript
import {VisualTest, VisualTestPropHelper} from "@solution5520/s-visual-test"

export default {
  components: {
    VisualTest
  },
  data() {
    return {
      componentFilename: "CustomInput",
      defaultValue: "some text",
      model: "some text in a variable",
      events: ["input", "change"],
      methods: ["focus"]
    };
  },
  computed: {
    props() {
      return [
        new VisualTestPropHelper("value with long text", [
          {
            value:
              "Lorem ipsum dolor sit amet, consectetur adipiscing elit. Nulla vel libero dapibus, varius urna et, bibendum sapien. Fusce tincidunt quam vel eleifend laoreet. Fusce purus turpis, sodales vehicula sem sit amet, molestie eleifend nunc. Suspendisse suscipit mattis porttitor. Ut suscipit scelerisque varius. Curabitur sit amet ultrices felis, nec mattis metus. Cras semper euismod lorem, sed aliquet metus. Donec elit libero, sollicitudin vel porta tristique, cursus ac justo. Praesent blandit luctus commodo."
          }
        ]),
        new VisualTestPropHelper("readonly", [
          { readonly: true },
          {
            readonly: true,
            value: this.defaultValue
          }
        ]),
        new VisualTestPropHelper("disabled", [
          { disabled: true },
          {
            disabled: true,
            value: this.defaultValue
          }
        ]),
        new VisualTestPropHelper("placeholder", [{ placeholder: "somePlaceholder" }])
      ];
    }
  }
};
```


## Props

name | type | default value | description
---- | ---- | ------------- | -----------
componentFilename | String | null | Component file name under `src/components/[filename]`.
defaultValue | Object | null | A common value for the tested component.
value | Object | null | A common value to test the reactivity of the tested component.
props | Array | new Array | A list of `VisualTestPropHelper` like object to test each property.
events | Array | new Array | The names of events to test.
methods | Array | new Array | The names of component's methods to test.